<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Utilities;
use Teknisa\MAN\Services\NovoCodigo;
use Teknisa\MAN\Services\MovCaixaBD;

class Confcaixa extends \Teknisa\MAN\Controllers\TeknisaCrud {
    
	protected $dataSourceName = 'vnd01900_conferenciacaixa';
	protected $crudService;
	protected $novoCodigo;
    protected $environment;
	protected $movCaixaBD;
	protected $ConfCaixaService;
	protected $util;
	protected $parameterBagColumns = array('CDFILIAL', 'DTCAIXA', 'CDLOJA', 'NRORG');
    
    public function __construct($crudService, NovoCodigo $novoCodigo, MovCaixaBD $movCaixaBD, $ConfCaixaService, $environment, Utilities\Util $util) {
        $this->crudService      = $crudService;
        $this->novoCodigo       = $novoCodigo;
        $this->environment      = $environment;
        $this->movCaixaBD       = $movCaixaBD;
        $this->ConfCaixaService = $ConfCaixaService;
        $this->util             = $util;
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $row = $this->util->getParamsAsArray($request);
        $verification = $this->ConfCaixaService->verifyOpenCaixa($row);
        if(count($verification) > 0){
            $response->addMessage(new Message("Não é possível realizar a Conferência para a Loja: ".$verification[0]['LABELLOJA'].
                                              " o Caixa: ".$verification[0]['LABELCAIXA']." se encontra em aberto!", Message::TYPE_ERROR));
        } else {
            $this->dataSourceName = 'vnd01900_conferenciacaixa';
            $this->parameterBagColumns = $this->parameterBagColumns;
            parent::find($request, $response);
        }
    }
    
    public function saveInLine(DTO\Request\DataSet $request, DTO\Response $response) {
        $rows = $request->getDataSet()->getRows();
        foreach ($rows as $row){
            if (isset($row['CDFILIAL']) && isset($row['CDTIPORECE']) && isset($row['CDLOJA']) && isset($row['DTCAIXA'])) {
                $verification = $this->ConfCaixaService->verifyCaixaConferido($row);
                if($verification){
                    $this->ConfCaixaService->updateConfCaixa($row);
                } else {
                    $this->ConfCaixaService->insertConfCaixa($row);
                }
            }
        }
    }
    
    public function select_loja(DTO\Request\Row $request, DTO\Response $response) {
        $conditions = $this->util->getParamsAsArray($request);
        $loja = $this->ConfCaixaService->get_Loja($conditions);
        $response->addDataSet(new DataSet('post_select_loja', $loja));
        return $response;
    }
    
    public function findIDCONFERCAIXA(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = 'vnd01900_conferenciacaixaIDCONFERCAIXA';
        $this->parameterBagColumns = $this->parameterBagColumns;
        parent::find($request, $response);
    }
    
}